@@ -95,7 +95,7 @@ gncal_day_panel_new (GnomeCalendar *calendar, time_t start_of_day)
 {
 	GncalDayPanel *dpanel;
 	GtkWidget *w;
-	struct tm *tm;
+	struct tm tm;
 
 	g_return_val_if_fail (calendar != NULL, NULL);
 
@@ -148,7 +148,7 @@ gncal_day_panel_new (GnomeCalendar *calendar, time_t start_of_day)
 
 	/* Gtk calendar */
 
-	tm = localtime (&start_of_day);
+	tm = *localtime (&start_of_day);
 
 	w = gtk_calendar_new ();
 	dpanel->gtk_calendar = GTK_CALENDAR (w);
@@ -157,8 +157,8 @@ gncal_day_panel_new (GnomeCalendar *calendar, time_t start_of_day)
 				       | GTK_CALENDAR_SHOW_DAY_NAMES
 				       | (week_starts_on_monday
 					  ? GTK_CALENDAR_WEEK_START_MONDAY : 0)));
-	gtk_calendar_select_month (dpanel->gtk_calendar, tm->tm_mon, tm->tm_year + 1900);
-	gtk_calendar_select_day (dpanel->gtk_calendar, tm->tm_mday);
+	gtk_calendar_select_month (dpanel->gtk_calendar, tm.tm_mon, tm.tm_year + 1900);
+	gtk_calendar_select_day (dpanel->gtk_calendar, tm.tm_mday);
 	dpanel->day_selected_id = gtk_signal_connect (GTK_OBJECT (dpanel->gtk_calendar),
 						      "day_selected_double_click",
 						      (GtkSignalFunc) calendar_day_selected,
