@@ -47,6 +47,9 @@ int week_starts_on_monday;
 /* If true, do not show our top level window */
 int startup_hidden = 0;
 
+/* If true, enable debug output for alarms */
+int debug_alarms = 0;
+
 /* The array of color properties -- keep in sync with the enumeration defined in main.h.  The color
  * values specified here are the defaults for the program.
  */
@@ -58,7 +61,9 @@ struct color_prop color_props[] = {
 	{ 0xd364, 0xc6b7, 0x7969, N_("Highlighted day:"),      "/calendar/Colors/prelight_bg" },
 	{ 0x01f0, 0x01f0, 0x01f0, N_("Day numbers:"),          "/calendar/Colors/day_fg" },
 	{ 0x0000, 0x0000, 0xffff, N_("Current day's number:"), "/calendar/Colors/current_fg" },
-	{ 0x0000, 0xaaaa, 0xaaaa, N_("Overdue To Do item"),     "/calendar/Coloirs/todo_overdue" }
+ 	{ 0xbbbb, 0xbbbb, 0x0000, N_("To-Do item that is not yet due:"), "/calendar/Colors/todo_not_yet" },
+ 	{ 0xdddd, 0xbbbb, 0x0000, N_("To-Do item that is due today:"),   "/calendar/Colors/todo_today" },
+ 	{ 0xbbbb, 0xdddd, 0x0000, N_("To-Do item that is overdue:"),     "/calendar/Colors/todo_overdue" }
 };
 
 /* Number of active calendars */
@@ -141,9 +146,14 @@ init_calendar (void)
 
 	/* read todolist settings */
 
+	todo_show_time_remaining = gnome_config_get_bool("/calendar/Todo/show_time_remain");
 	todo_show_due_date = gnome_config_get_bool("/calendar/Todo/show_due_date");
 
-	todo_due_date_overdue_highlight = gnome_config_get_bool("/calendar/Todo/highlight_overdue_tasks");
+	todo_item_dstatus_highlight_overdue = gnome_config_get_bool("/calendar/Todo/highlight_overdue");
+	
+	todo_item_dstatus_highlight_due_today = gnome_config_get_bool("/calendar/Todo/highlight_due_today");
+	
+	todo_item_dstatus_highlight_not_due_yet = gnome_config_get_bool("/calendar/Todo/highlight_not_due_yet");
 
         todo_current_sort_column = gnome_config_get_int("/calendar/Todo/sort_column");
 	
@@ -320,10 +330,22 @@ new_calendar_cmd (GtkWidget *widget, void *data)
 static void
 open_ok (GtkWidget *widget, GtkFileSelection *fs)
 {
-	/* FIXME: find out who owns this calendar and use that name */
-	new_calendar ("Somebody", gtk_file_selection_get_filename (fs), NULL, NULL, FALSE);
+	GtkWidget *error_dialog;
+	int ret;
+	if(!g_file_exists (gtk_file_selection_get_filename (fs))) {
+		error_dialog = gnome_message_box_new (
+			_("File not found"),
+			GNOME_MESSAGE_BOX_ERROR,
+			GNOME_STOCK_BUTTON_OK,
+			NULL);
 
-	gtk_widget_destroy (GTK_WIDGET (fs));
+		gnome_dialog_set_parent (GNOME_DIALOG (error_dialog), GTK_WINDOW (fs));
+		ret = gnome_dialog_run (GNOME_DIALOG (error_dialog));
+	} else {
+		/* FIXME: find out who owns this calendar and use that name */
+		new_calendar ("Somebody", gtk_file_selection_get_filename (fs), NULL, NULL, FALSE);
+		gtk_widget_destroy (GTK_WIDGET (fs));
+	}
 }
 
 static void
@@ -629,7 +651,8 @@ enum {
 	USERFILE_KEY = -2,
 	VIEW_KEY     = -3,
 	HIDDEN_KEY   = -4,
-	TODO_KEY     = -5
+	TODO_KEY     = -5,
+	DEBUG_KEY    = -6
 };
 
 /* Lists used to startup various GnomeCalendars */
@@ -769,6 +792,11 @@ parse_an_arg (poptContext ctx,
 	case HIDDEN_KEY:
 		startup_hidden = 1;
 		break;
+
+	case DEBUG_KEY:
+		if (!g_strcasecmp (arg, "alarms"))
+			debug_alarms = 1;
+		break;
 		
 	default:
 	}
@@ -787,6 +815,7 @@ static const struct poptOption options [] = {
 	{ "view", '\0', POPT_ARG_STRING, NULL, VIEW_KEY, N_("The startup view mode (dayview, weekview, monthview, yearview)"), N_("VIEW") },
 	{ "to", 't', POPT_ARG_STRING, NULL, 't', N_("Specifies ending date [for --events]"), N_("DATE") },
 	{ "hidden", 0, POPT_ARG_NONE, NULL, HIDDEN_KEY, N_("If used, starts in iconic mode"), NULL },
+	{ "debug", 'd', POPT_ARG_STRING, NULL, DEBUG_KEY, N_("Enable debugging output of TYPE (alarms)"), N_("TYPE") },
 	{ NULL, '\0', 0, NULL, 0}
 };
 
