@@ -24,11 +24,12 @@
 
 #include "card.h"
 #include "dialog.h"
-#include "addresslist.h"
+#include "deladdrlist.h"
 #include "phonelist.h"
 #include "gnomecard.h"
 #include "canvas.h"
 #include "dnd.h"
+#include "my.h"
 
 #define CARDNAME_FONTSET "-adobe-helvetica-medium-r-normal-*-18-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-20-*-*-*-p-*-koi8-r,-*-*-medium-r-normal-*-18-*-*-*-*-*-ksc5601.1987-0,*"
 #define TITLE_FONTSET "-adobe-helvetica-medium-r-*-*-14-*-*-*-p-*-*-*,-cronyx-helvetica-medium-r-normal-*-17-*-*-*-p-*-koi8-r,-*-*-medium-r-no-*-*-14-*-*-*-*-*-ksc5601.1987-0,*"
@@ -57,7 +58,7 @@ typedef struct {
 
 GtkWidget *gnomecard_canvas;
 static GnomeCanvasItem *cardname, *fullname, *workphone, *homephone;
-static GnomeCanvasItem *cardname_box, *phone_box, *postal_box, *categories_box, *memo_box;
+static GnomeCanvasItem *cardname_box, *phone_box, *deladdr_box, *categories_box, *memo_box;
 static GnomeCanvasItem *email, *url, *org, *title, *categories, *memos;
 static CanvasAddressItem homeaddr, workaddr;
 static GnomeCanvasGroup *root;
@@ -247,7 +248,7 @@ gnomecard_canvas_new(void)
 
 	/* addresses */
 	ypos += LIST_SPACING;
-	postal_box = gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
+	deladdr_box = gnome_canvas_item_new (root, gnome_canvas_rect_get_type (),
 			       "x1", 5.0,
 			       "y1", ypos,
 			       "x2", (double) (CANVAS_WIDTH - 6.0),
@@ -537,11 +538,10 @@ gnomecard_update_canvas(Card *crd)
 		gdk_font_unref(font);
 		
 		width = MAX(CANVAS_WIDTH - 6.0, width + 7.0);
-		
 		gnomecard_canvas_text_item_set(cardname, str);
 		gnome_canvas_item_set(cardname_box, "x2", width, NULL);
 		gnome_canvas_item_set(phone_box, "x2", width, NULL);
-		gnome_canvas_item_set(postal_box, "x2", width, NULL);
+		gnome_canvas_item_set(deladdr_box, "x2", width, NULL);
 		gnome_canvas_item_set(categories_box, "x2", width, NULL);
 		gnome_canvas_item_set(memo_box, "x2", width, NULL);
 	}
@@ -563,28 +563,29 @@ gnomecard_update_canvas(Card *crd)
 	gnomecard_canvas_text_item_set(org, crd->org.name);
 	
 	/* email and web site */
-	gnomecard_canvas_text_item_set(email, crd->email.address);
+	if (crd->email.l)
+	  gnomecard_canvas_text_item_set
+	  	(email, ((CardEMail *) crd->email.l->data)->data);
 
 	if (crd->url.str)
-		gnomecard_canvas_text_item_set(url, crd->url.str);
+	  gnomecard_canvas_text_item_set(url, crd->url.str);
 	else
-		gnomecard_canvas_text_item_set(url, "");
+	  gnomecard_canvas_text_item_set(url, "");
 	
 	/* phone numbers */
 	if (crd->phone.l) {
 		GList *l;
 		
-		l = findmatchPhoneType(crd->phone.l, PHONE_HOME);
+		l = phonelist_find_by_type (crd->phone.l, PHONE_HOME);
 		if (l) {
-	    CardPhone *phone;
-	    
-	    phone = (CardPhone *)l->data;
-	    gnomecard_canvas_text_item_set(homephone, phone->data);
-		} else {
-	    gnomecard_canvas_text_item_set(homephone, "");
-		}	    
+			CardPhone *phone;
+			
+			phone = (CardPhone *)l->data;
+			gnomecard_canvas_text_item_set(homephone, phone->data);
+		} else
+		  gnomecard_canvas_text_item_set(homephone, "");
 		
-		l = findmatchPhoneType(crd->phone.l, PHONE_WORK);
+		l = phonelist_find_by_type (crd->phone.l, PHONE_WORK);
 		if (l) {
 	    CardPhone *phone;
 	    
@@ -599,69 +600,75 @@ gnomecard_update_canvas(Card *crd)
 	}	
 	
 	/* address */
-	if (crd->postal.l) {
-		l = findmatchAddrType(crd->postal.l, ADDR_HOME);
+	if (crd->deladdr.l) {
+		l = deladdrlist_find_by_type(crd->deladdr.l, ADDR_HOME);
 		if (l) {
-	    gchar tmp[200];
+			gchar tmp[200];
 			gchar *fmt1 = "%s, %s   %s";
 			gchar *fmt2 = "%s%s  %s";
 			gchar *fmt;
 
-	    CardPostAddr *p=(CardPostAddr *)l->data;
+			CardDelAddr *p = (CardDelAddr *) l->data;
 			
-			if (p->city && *p->city && p->state && *p->state)
+			if (p->data[CITY] && *p->data[CITY] && 
+			    p->data[REGION] && *p->data[REGION])
 				fmt = fmt1;
 			else
 				fmt = fmt2;
 			
-	    gnomecard_canvas_text_item_set(homeaddr.street1, 
-																		 (p->street1) ? p->street1 : "");
-	    gnomecard_canvas_text_item_set(homeaddr.street2,  
-																		 (p->street2) ? p->street2 : "");
+			gnomecard_canvas_text_item_set(homeaddr.street1, 
+						       MY_STR(p->data[EXT]));
+			gnomecard_canvas_text_item_set(homeaddr.street2,  
+						       MY_STR(p->data[STREET]));
 			
-	    snprintf(tmp, sizeof(tmp), fmt, 
-							 (p->city) ? p->city : "", (p->state) ? p->state : "",
-							 (p->zip) ? p->zip : "");
-	    gnomecard_canvas_text_item_set(homeaddr.state, tmp);
-	    gnomecard_canvas_text_item_set(homeaddr.country, 
-																		 (p->country) ? p->country : "");
+			snprintf(tmp, sizeof(tmp), fmt, 
+				 MY_STR(p->data[CITY]),
+				 MY_STR(p->data[REGION]),
+				 MY_STR(p->data[CODE]));
+			
+			gnomecard_canvas_text_item_set(homeaddr.state, tmp);
+			gnomecard_canvas_text_item_set(homeaddr.country, 
+						       MY_STR(p->data[COUNTRY]));
 		} else {
-	    gnomecard_canvas_text_item_set(homeaddr.street1, "");
-	    gnomecard_canvas_text_item_set(homeaddr.street2, "");
-	    gnomecard_canvas_text_item_set(homeaddr.state, "");
-	    gnomecard_canvas_text_item_set(homeaddr.country, "");
+			gnomecard_canvas_text_item_set(homeaddr.street1, "");
+			gnomecard_canvas_text_item_set(homeaddr.street2, "");
+			gnomecard_canvas_text_item_set(homeaddr.state, "");
+			gnomecard_canvas_text_item_set(homeaddr.country, "");
 		}
 		
-		l = findmatchAddrType(crd->postal.l, ADDR_WORK);
+		l = deladdrlist_find_by_type(crd->deladdr.l, ADDR_WORK);
 		if (l) {
-	    gchar tmp[200];	
+			gchar tmp[200];	
 			gchar *fmt1 = "%s, %s   %s";
 			gchar *fmt2 = "%s%s  %s";
 			gchar *fmt;
 
-	    CardPostAddr *p=(CardPostAddr *)l->data;
+			CardDelAddr *p = (CardDelAddr *) l->data;
 			
-			if (p->city && *p->city && p->state && *p->state)
-				fmt = fmt1;
+			if (p->data[CITY] && *p->data[CITY] && 
+			    p->data[REGION] && *p->data[REGION])
+			  fmt = fmt1;
 			else
-				fmt = fmt2;
+			  fmt = fmt2;
 			
-	    gnomecard_canvas_text_item_set(workaddr.street1, 
-																		 (p->street1) ? p->street1 : "");
-	    gnomecard_canvas_text_item_set(workaddr.street2,  
-																		 (p->street2) ? p->street2 : "");
+			gnomecard_canvas_text_item_set(workaddr.street1, 
+						       MY_STR(p->data[EXT]));
+			gnomecard_canvas_text_item_set(workaddr.street2,
+						       MY_STR(p->data[STREET]));
+
+			snprintf(tmp, sizeof(tmp), fmt, 
+				 MY_STR(p->data[CITY]),
+				 MY_STR(p->data[REGION]),
+				 MY_STR(p->data[CODE]));
 			
-	    snprintf(tmp, sizeof(tmp), fmt,
-							 (p->city) ? p->city : "", (p->state) ? p->state : "",
-							 (p->zip) ? p->zip : "");
-	    gnomecard_canvas_text_item_set(workaddr.state, tmp);
-	    gnomecard_canvas_text_item_set(workaddr.country, 
-																		 (p->country) ? p->country : "");
+			gnomecard_canvas_text_item_set(workaddr.state, tmp);
+			gnomecard_canvas_text_item_set(homeaddr.country, 
+						       MY_STR(p->data[COUNTRY]));
 		} else {
-	    gnomecard_canvas_text_item_set(workaddr.street1, "");
-	    gnomecard_canvas_text_item_set(workaddr.street2, "");
-	    gnomecard_canvas_text_item_set(workaddr.state, "");
-	    gnomecard_canvas_text_item_set(workaddr.country, "");
+			gnomecard_canvas_text_item_set(workaddr.street1, "");
+			gnomecard_canvas_text_item_set(workaddr.street2, "");
+			gnomecard_canvas_text_item_set(workaddr.state, "");
+			gnomecard_canvas_text_item_set(workaddr.country, "");
 		}
 	} else {
 		gnomecard_canvas_text_item_set(homeaddr.street1, "");
