@@ -320,15 +320,15 @@ gnomecard_cmp_emails(const void *crd1, const void *crd2)
 	card1 = (* (Card **) crd1);
 	card2 = (* (Card **) crd2);
 
-	if (! card1->email.address && !card2->email.address)
+	if (! card1->email.l && !card2->email.l)
 	  return gnomecard_cmp_fnames(crd1, crd2);
-	if (! card1->email.address)
+	if (! card1->email.l)
 	  return 1;
-	if (! card2->email.address)
+	if (! card2->email.l)
 	  return -1;
 	
-	email1 = g_strdup(card1->email.address);
-	email2 = g_strdup(card2->email.address);
+	email1 = g_strdup(((CardEMail *) card1->email.l->data)->data);
+	email2 = g_strdup(((CardEMail *) card2->email.l->data)->data);
 	
 	if ((host1 = strchr(email1, '@'))) {
 		*host1++ = 0;
